@@ -2,7 +2,7 @@ from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
-SQLALCHEMY_DATABASE_URI = "postgres://seon:seon@localhost/sspo_ontology"
+SQLALCHEMY_DATABASE_URI = "postgres://postgres:1234@localhost/sro_ontology3"
 engine = create_engine(SQLALCHEMY_DATABASE_URI)
 session = sessionmaker(bind=engine)
 session = session()
